/* SerializableBasicTypesTest.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializableBasicTypesTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_BASIC_TYPE_TEST (serializable_basic_type_test_get_type ())
#define SERIALIZABLE_BASIC_TYPE_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_BASIC_TYPE_TEST, SerializableBasicTypeTest))
#define SERIALIZABLE_BASIC_TYPE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_BASIC_TYPE_TEST, SerializableBasicTypeTestClass))
#define IS_SERIALIZABLE_BASIC_TYPE_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_BASIC_TYPE_TEST))
#define IS_SERIALIZABLE_BASIC_TYPE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_BASIC_TYPE_TEST))
#define SERIALIZABLE_BASIC_TYPE_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_BASIC_TYPE_TEST, SerializableBasicTypeTestClass))

typedef struct _SerializableBasicTypeTest SerializableBasicTypeTest;
typedef struct _SerializableBasicTypeTestClass SerializableBasicTypeTestClass;
typedef struct _SerializableBasicTypeTestPrivate SerializableBasicTypeTestPrivate;

#define SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE (serializable_basic_type_test_basic_type_get_type ())
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType))
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicTypeClass))
#define SERIALIZABLE_BASIC_TYPE_TEST_IS_BASIC_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE))
#define SERIALIZABLE_BASIC_TYPE_TEST_IS_BASIC_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE))
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicTypeClass))

typedef struct _SerializableBasicTypeTestBasicType SerializableBasicTypeTestBasicType;
typedef struct _SerializableBasicTypeTestBasicTypeClass SerializableBasicTypeTestBasicTypeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializableBasicTypeTestBasicTypePrivate SerializableBasicTypeTestBasicTypePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableBasicTypeTest {
	GXmlTest parent_instance;
	SerializableBasicTypeTestPrivate * priv;
};

struct _SerializableBasicTypeTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableBasicTypeTestBasicType {
	GXmlSerializableObjectModel parent_instance;
	SerializableBasicTypeTestBasicTypePrivate * priv;
};

struct _SerializableBasicTypeTestBasicTypeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableBasicTypeTestBasicTypePrivate {
	gboolean _boolean;
	gint _integer;
	gfloat _floatval;
	gdouble _doubleval;
};


static gpointer serializable_basic_type_test_parent_class = NULL;
static gpointer serializable_basic_type_test_basic_type_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_basic_type_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_BASIC_TYPE_TEST_DUMMY_PROPERTY
};
void serializable_basic_type_test_add_tests (void);
static void __lambda72_ (void);
GType serializable_basic_type_test_basic_type_get_type (void) G_GNUC_CONST;
SerializableBasicTypeTestBasicType* serializable_basic_type_test_basic_type_new (void);
SerializableBasicTypeTestBasicType* serializable_basic_type_test_basic_type_construct (GType object_type);
void serializable_basic_type_test_basic_type_set_boolean (SerializableBasicTypeTestBasicType* self, gboolean value);
static void ___lambda72__gtest_func (void);
static void __lambda73_ (void);
gboolean serializable_basic_type_test_basic_type_get_boolean (SerializableBasicTypeTestBasicType* self);
static void ___lambda73__gtest_func (void);
static void __lambda74_ (void);
gint serializable_basic_type_test_basic_type_get_integer (SerializableBasicTypeTestBasicType* self);
static void ___lambda74__gtest_func (void);
static void __lambda75_ (void);
gfloat serializable_basic_type_test_basic_type_get_floatval (SerializableBasicTypeTestBasicType* self);
void serializable_basic_type_test_basic_type_set_floatval (SerializableBasicTypeTestBasicType* self, gfloat value);
static void ___lambda75__gtest_func (void);
static void __lambda76_ (void);
gdouble serializable_basic_type_test_basic_type_get_doubleval (SerializableBasicTypeTestBasicType* self);
void serializable_basic_type_test_basic_type_set_doubleval (SerializableBasicTypeTestBasicType* self, gdouble value);
static void ___lambda76__gtest_func (void);
SerializableBasicTypeTest* serializable_basic_type_test_new (void);
SerializableBasicTypeTest* serializable_basic_type_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicTypePrivate))
enum  {
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DUMMY_PROPERTY,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL
};
static gchar* serializable_basic_type_test_basic_type_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_basic_type_test_basic_type_real_to_string (GXmlSerializableObjectModel* base);
void serializable_basic_type_test_basic_type_set_integer (SerializableBasicTypeTestBasicType* self, gint value);
static void serializable_basic_type_test_basic_type_finalize (GObject* obj);
static void _vala_serializable_basic_type_test_basic_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_basic_type_test_basic_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 157 "SerializableBasicTypesTest.c"
}


static void __lambda72_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlElement* element = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlElement* _tmp6_ = NULL;
		GXmlNode* b = NULL;
		GXmlNode* _tmp7_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (bt, TRUE);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc = _tmp1_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bt, (GXmlNode*) doc, &_inner_error_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp3_ = _tmp2_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (_tmp3_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 204 "SerializableBasicTypesTest.c"
			goto __catch100_g_error;
		}
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp5_ = _tmp4_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp5_) : NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (_tmp6_ == NULL) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (_tmp5_);
#line 217 "SerializableBasicTypesTest.c"
		}
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		element = _tmp6_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp7_ = gxml_element_get_attr (element, "boolean");
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		b = _tmp7_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (b == NULL) {
#line 227 "SerializableBasicTypesTest.c"
			FILE* _tmp8_ = NULL;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp8_ = stdout;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			fprintf (_tmp8_, "%s", "ERROR: No boolean exists\n");
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			g_assert_not_reached ();
#line 235 "SerializableBasicTypesTest.c"
		}
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp9_ = gxml_node_get_value (b);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp10_ = _tmp9_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp11_ = _tmp10_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp12_ = g_utf8_strdown (_tmp11_, (gssize) -1);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp14_ = g_strcmp0 (_tmp13_, "true") != 0;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp13_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp11_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (_tmp14_) {
#line 255 "SerializableBasicTypesTest.c"
			FILE* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			const gchar* _tmp25_ = NULL;
			gchar* _tmp26_ = NULL;
			gchar* _tmp27_ = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp15_ = stdout;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp16_ = gxml_node_get_value (b);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp17_ = _tmp16_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp18_ = _tmp17_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp19_ = g_utf8_strdown (_tmp18_, (gssize) -1);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp20_ = _tmp19_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp21_ = string_to_string (_tmp20_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp22_ = gxml_node_get_value (b);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp23_ = _tmp22_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp24_ = _tmp23_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp25_ = string_to_string (_tmp24_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp26_ = g_strconcat ("ERROR: Wrong boolean value. Expected true got: ", _tmp21_, " : ", _tmp25_, "\n", NULL);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp27_ = _tmp26_;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			fprintf (_tmp15_, "%s", _tmp27_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp27_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp24_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp20_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp18_);
#line 53 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			g_assert_not_reached ();
#line 307 "SerializableBasicTypesTest.c"
		}
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (b);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (element);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 317 "SerializableBasicTypesTest.c"
	}
	goto __finally100;
	__catch100_g_error:
	{
		GError* e = NULL;
		FILE* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		e = _inner_error_;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_inner_error_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp28_ = stdout;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp29_ = e->message;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp30_ = string_to_string (_tmp29_);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp31_ = g_strconcat ("ERROR: ", _tmp30_, NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp32_ = _tmp31_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		fprintf (_tmp28_, "%s", _tmp32_);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp32_);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 350 "SerializableBasicTypesTest.c"
	}
	__finally100:
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error_);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		return;
#line 361 "SerializableBasicTypesTest.c"
	}
}


static void ___lambda72__gtest_func (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	__lambda72_ ();
#line 369 "SerializableBasicTypesTest.c"
}


static gchar* bool_to_string (gboolean self) {
	gchar* result = NULL;
#line 37 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	if (self) {
#line 377 "SerializableBasicTypesTest.c"
		gchar* _tmp0_ = NULL;
#line 38 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp0_ = g_strdup ("true");
#line 38 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		result = _tmp0_;
#line 38 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 385 "SerializableBasicTypesTest.c"
	} else {
		gchar* _tmp1_ = NULL;
#line 40 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp1_ = g_strdup ("false");
#line 40 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		result = _tmp1_;
#line 40 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 394 "SerializableBasicTypesTest.c"
	}
}


static void __lambda73_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp1_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype boolean=\"true\"/>", 0, &_inner_error_);
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 428 "SerializableBasicTypesTest.c"
			goto __catch101_g_error;
		}
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error_);
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 443 "SerializableBasicTypesTest.c"
			goto __catch101_g_error;
		}
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_boolean (_tmp5_);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (_tmp7_ != TRUE) {
#line 454 "SerializableBasicTypesTest.c"
			FILE* _tmp8_ = NULL;
			SerializableBasicTypeTestBasicType* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
			gchar* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			GXmlGDocument* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp8_ = stdout;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp9_ = bt;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp10_ = serializable_basic_type_test_basic_type_get_boolean (_tmp9_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp11_ = _tmp10_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp12_ = bool_to_string (_tmp11_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp13_ = _tmp12_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp14_ = doc;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp15_ = gxml_gnode_to_string ((GXmlGNode*) _tmp14_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp16_ = _tmp15_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp17_ = g_strconcat ("ERROR: Wrong boolean value. Expected true got: ", _tmp13_, "\n", _tmp16_, "\n", NULL);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_tmp18_ = _tmp17_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			fprintf (_tmp8_, "%s", _tmp18_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp18_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp16_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_free0 (_tmp13_);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			g_assert_not_reached ();
#line 498 "SerializableBasicTypesTest.c"
		}
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 504 "SerializableBasicTypesTest.c"
	}
	goto __finally101;
	__catch101_g_error:
	{
		GError* e = NULL;
		FILE* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		e = _inner_error_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_inner_error_ = NULL;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp19_ = stdout;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp20_ = e->message;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp21_ = string_to_string (_tmp20_);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp22_ = g_strconcat ("ERROR: ", _tmp21_, NULL);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp23_ = _tmp22_;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		fprintf (_tmp19_, "%s", _tmp23_);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp23_);
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 537 "SerializableBasicTypesTest.c"
	}
	__finally101:
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error_);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		return;
#line 548 "SerializableBasicTypesTest.c"
	}
}


static void ___lambda73__gtest_func (void) {
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	__lambda73_ ();
#line 556 "SerializableBasicTypesTest.c"
}


static void __lambda74_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp1_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp9_ = NULL;
		GXmlGDocument* _tmp10_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp15_ = NULL;
		GXmlGDocument* _tmp16_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp20_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp21_ = NULL;
		GXmlGDocument* _tmp22_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp23_ = NULL;
		gint _tmp24_ = 0;
		gint _tmp25_ = 0;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp26_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp27_ = NULL;
		GXmlGDocument* _tmp28_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp29_ = NULL;
		gint _tmp30_ = 0;
		gint _tmp31_ = 0;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp32_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp33_ = NULL;
		GXmlGDocument* _tmp34_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp35_ = NULL;
		gint _tmp36_ = 0;
		gint _tmp37_ = 0;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp38_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp39_ = NULL;
		GXmlGDocument* _tmp40_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp41_ = NULL;
		gint _tmp42_ = 0;
		gint _tmp43_ = 0;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156\"/>", 0, &_inner_error_);
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 631 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error_);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 646 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_integer (_tmp5_);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp7_ == 156, "bt.integer == 156");
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"a156\"/>", 0, &_inner_error_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc1 = _tmp8_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 667 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp9_ = bt;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp10_ = doc1;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp9_, (GXmlNode*) _tmp10_, &_inner_error_);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 684 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp11_ = bt;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp12_ = serializable_basic_type_test_basic_type_get_integer (_tmp11_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp13_ == 0, "bt.integer == 0");
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp14_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156b\"/>", 0, &_inner_error_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc2 = _tmp14_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 707 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp15_ = bt;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp16_ = doc2;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp15_, (GXmlNode*) _tmp16_, &_inner_error_);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 726 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp17_ = bt;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp18_ = serializable_basic_type_test_basic_type_get_integer (_tmp17_);
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp19_ = _tmp18_;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp19_ == 156, "bt.integer == 156");
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp20_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156.0\"/>", 0, &_inner_error_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc3 = _tmp20_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 751 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp21_ = bt;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp22_ = doc3;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp21_, (GXmlNode*) _tmp22_, &_inner_error_);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 772 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp23_ = bt;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp24_ = serializable_basic_type_test_basic_type_get_integer (_tmp23_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp25_ = _tmp24_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp25_ == 156, "bt.integer == 156");
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"0.156\"/>", 0, &_inner_error_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc4 = _tmp26_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 799 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp27_ = bt;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp28_ = doc4;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp27_, (GXmlNode*) _tmp28_, &_inner_error_);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 822 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp29_ = bt;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp30_ = serializable_basic_type_test_basic_type_get_integer (_tmp29_);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp31_ = _tmp30_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp31_ == 0, "bt.integer == 0");
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp32_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"a156.156\"/>", 0, &_inner_error_);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc5 = _tmp32_;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 851 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp33_ = bt;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp34_ = doc5;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp33_, (GXmlNode*) _tmp34_, &_inner_error_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 876 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp35_ = bt;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp36_ = serializable_basic_type_test_basic_type_get_integer (_tmp35_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp37_ = _tmp36_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp37_ == 0, "bt.integer == 0");
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp38_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156.156b\"/>", 0, &_inner_error_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc6 = _tmp38_;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 907 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp39_ = bt;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp40_ = doc6;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp39_, (GXmlNode*) _tmp40_, &_inner_error_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 934 "SerializableBasicTypesTest.c"
			goto __catch102_g_error;
		}
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp41_ = bt;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp42_ = serializable_basic_type_test_basic_type_get_integer (_tmp41_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp43_ = _tmp42_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp43_ == 156, "bt.integer == 156");
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc6);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc5);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc4);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc3);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc2);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc1);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 961 "SerializableBasicTypesTest.c"
	}
	goto __finally102;
	__catch102_g_error:
	{
		GError* e = NULL;
		FILE* _tmp44_ = NULL;
		const gchar* _tmp45_ = NULL;
		const gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		e = _inner_error_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_inner_error_ = NULL;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp44_ = stdout;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp45_ = e->message;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp46_ = string_to_string (_tmp45_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp47_ = g_strconcat ("ERROR: ", _tmp46_, NULL);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp48_ = _tmp47_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		fprintf (_tmp44_, "%s", _tmp48_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp48_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 994 "SerializableBasicTypesTest.c"
	}
	__finally102:
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		return;
#line 1005 "SerializableBasicTypesTest.c"
	}
}


static void ___lambda74__gtest_func (void) {
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	__lambda74_ ();
#line 1013 "SerializableBasicTypesTest.c"
}


static void __lambda75_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp1_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp5_ = NULL;
		gfloat _tmp6_ = 0.0F;
		gfloat _tmp7_ = 0.0F;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp9_ = NULL;
		GXmlGDocument* _tmp10_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp11_ = NULL;
		gfloat _tmp12_ = 0.0F;
		gfloat _tmp13_ = 0.0F;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp15_ = NULL;
		GXmlGDocument* _tmp16_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp17_ = NULL;
		gfloat _tmp18_ = 0.0F;
		gfloat _tmp19_ = 0.0F;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp20_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp21_ = NULL;
		GXmlGDocument* _tmp22_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp23_ = NULL;
		gfloat _tmp24_ = 0.0F;
		gfloat _tmp25_ = 0.0F;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp26_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp27_ = NULL;
		GXmlGDocument* _tmp28_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp29_ = NULL;
		gfloat _tmp30_ = 0.0F;
		gfloat _tmp31_ = 0.0F;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp32_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp33_ = NULL;
		GXmlGDocument* _tmp34_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp35_ = NULL;
		gfloat _tmp36_ = 0.0F;
		gfloat _tmp37_ = 0.0F;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp38_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp39_ = NULL;
		GXmlGDocument* _tmp40_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp41_ = NULL;
		gfloat _tmp42_ = 0.0F;
		gfloat _tmp43_ = 0.0F;
		GXmlGDocument* doc7 = NULL;
		GXmlGDocument* _tmp44_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp45_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp46_ = NULL;
		GXmlGDocument* _tmp47_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp48_ = NULL;
		gfloat _tmp49_ = 0.0F;
		gfloat _tmp50_ = 0.0F;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156\"/>", 0, &_inner_error_);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1096 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1111 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_floatval (_tmp5_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp7_) == 156.0, "bt.floatval == 156.0");
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"a156\"/>", 0, &_inner_error_);
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc1 = _tmp8_;
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1132 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp9_ = bt;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp10_ = doc1;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp9_, (GXmlNode*) _tmp10_, &_inner_error_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1149 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp11_ = bt;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp12_ = serializable_basic_type_test_basic_type_get_floatval (_tmp11_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp13_) == 0.0, "bt.floatval == 0.0");
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp14_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156b\"/>", 0, &_inner_error_);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc2 = _tmp14_;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1172 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp15_ = bt;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp16_ = doc2;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp15_, (GXmlNode*) _tmp16_, &_inner_error_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1191 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp17_ = bt;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp18_ = serializable_basic_type_test_basic_type_get_floatval (_tmp17_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp19_ = _tmp18_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp19_) == 156.0, "bt.floatval == 156.0");
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp20_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156.0\"/>", 0, &_inner_error_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc3 = _tmp20_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1216 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp21_ = bt;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp22_ = doc3;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp21_, (GXmlNode*) _tmp22_, &_inner_error_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1237 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp23_ = bt;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp24_ = serializable_basic_type_test_basic_type_get_floatval (_tmp23_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp25_ = _tmp24_;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp25_) == 156.0, "bt.floatval == 156.0");
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"0.156\"/>", 0, &_inner_error_);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc4 = _tmp26_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1264 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp27_ = bt;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp28_ = doc4;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp27_, (GXmlNode*) _tmp28_, &_inner_error_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1287 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp29_ = bt;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp30_ = serializable_basic_type_test_basic_type_get_floatval (_tmp29_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp31_ = _tmp30_;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp31_ == ((gfloat) 0.156), "bt.floatval == (float) 0.156");
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp32_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"a156.156\"/>", 0, &_inner_error_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc5 = _tmp32_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1316 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp33_ = bt;
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp34_ = doc5;
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp33_, (GXmlNode*) _tmp34_, &_inner_error_);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1341 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp35_ = bt;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp36_ = serializable_basic_type_test_basic_type_get_floatval (_tmp35_);
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp37_ = _tmp36_;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp37_) == 0.0, "bt.floatval == 0.0");
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp38_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156.156b\"/>", 0, &_inner_error_);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc6 = _tmp38_;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1372 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp39_ = bt;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp40_ = doc6;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp39_, (GXmlNode*) _tmp40_, &_inner_error_);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1399 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp41_ = bt;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp42_ = serializable_basic_type_test_basic_type_get_floatval (_tmp41_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp43_ = _tmp42_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp43_ == ((gfloat) 156.156), "bt.floatval == (float) 156.156");
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp44_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype boolean=\"true\"/>", 0, &_inner_error_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc7 = _tmp44_;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1432 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp45_ = bt;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_floatval (_tmp45_, (gfloat) 0.0);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp46_ = bt;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp47_ = doc7;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp46_, (GXmlNode*) _tmp47_, &_inner_error_);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc7);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1465 "SerializableBasicTypesTest.c"
			goto __catch103_g_error;
		}
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp48_ = bt;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp49_ = serializable_basic_type_test_basic_type_get_floatval (_tmp48_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp50_ = _tmp49_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp50_) == 0.0, "bt.floatval == 0.0");
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc7);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc6);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc5);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc4);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc3);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc2);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc1);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 1494 "SerializableBasicTypesTest.c"
	}
	goto __finally103;
	__catch103_g_error:
	{
		GError* e = NULL;
		FILE* _tmp51_ = NULL;
		const gchar* _tmp52_ = NULL;
		const gchar* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		e = _inner_error_;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_inner_error_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp51_ = stdout;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp52_ = e->message;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp53_ = string_to_string (_tmp52_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp54_ = g_strconcat ("ERROR: ", _tmp53_, NULL);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp55_ = _tmp54_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		fprintf (_tmp51_, "%s", _tmp55_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp55_);
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 1527 "SerializableBasicTypesTest.c"
	}
	__finally103:
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		return;
#line 1538 "SerializableBasicTypesTest.c"
	}
}


static void ___lambda75__gtest_func (void) {
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	__lambda75_ ();
#line 1546 "SerializableBasicTypesTest.c"
}


static void __lambda76_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp1_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp5_ = NULL;
		gdouble _tmp6_ = 0.0;
		gdouble _tmp7_ = 0.0;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp9_ = NULL;
		GXmlGDocument* _tmp10_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp11_ = NULL;
		gdouble _tmp12_ = 0.0;
		gdouble _tmp13_ = 0.0;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp15_ = NULL;
		GXmlGDocument* _tmp16_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp17_ = NULL;
		gdouble _tmp18_ = 0.0;
		gdouble _tmp19_ = 0.0;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp20_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp21_ = NULL;
		GXmlGDocument* _tmp22_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp23_ = NULL;
		gdouble _tmp24_ = 0.0;
		gdouble _tmp25_ = 0.0;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp26_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp27_ = NULL;
		GXmlGDocument* _tmp28_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp29_ = NULL;
		gdouble _tmp30_ = 0.0;
		gdouble _tmp31_ = 0.0;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp32_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp33_ = NULL;
		GXmlGDocument* _tmp34_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp35_ = NULL;
		gdouble _tmp36_ = 0.0;
		gdouble _tmp37_ = 0.0;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp38_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp39_ = NULL;
		GXmlGDocument* _tmp40_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp41_ = NULL;
		gdouble _tmp42_ = 0.0;
		gdouble _tmp43_ = 0.0;
		GXmlGDocument* doc7 = NULL;
		GXmlGDocument* _tmp44_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp45_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp46_ = NULL;
		GXmlGDocument* _tmp47_ = NULL;
		SerializableBasicTypeTestBasicType* _tmp48_ = NULL;
		gdouble _tmp49_ = 0.0;
		gdouble _tmp50_ = 0.0;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156\"/>", 0, &_inner_error_);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1629 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error_);
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1644 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp5_);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp7_ == 156.0, "bt.doubleval == 156.0");
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"a156\"/>", 0, &_inner_error_);
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc1 = _tmp8_;
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1665 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp9_ = bt;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp10_ = doc1;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp9_, (GXmlNode*) _tmp10_, &_inner_error_);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1682 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp11_ = bt;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp12_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp11_);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp13_ == 0.0, "bt.doubleval == 0.0");
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp14_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156b\"/>", 0, &_inner_error_);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc2 = _tmp14_;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1705 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp15_ = bt;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp16_ = doc2;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp15_, (GXmlNode*) _tmp16_, &_inner_error_);
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1724 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp17_ = bt;
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp18_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp17_);
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp19_ = _tmp18_;
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp19_ == 156.0, "bt.doubleval == 156.0");
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp20_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156.0\"/>", 0, &_inner_error_);
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc3 = _tmp20_;
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1749 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp21_ = bt;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp22_ = doc3;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp21_, (GXmlNode*) _tmp22_, &_inner_error_);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1770 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp23_ = bt;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp24_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp23_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp25_ = _tmp24_;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp25_ == 156.0, "bt.doubleval == 156.0");
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"0.156\"/>", 0, &_inner_error_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc4 = _tmp26_;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1797 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp27_ = bt;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp28_ = doc4;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp27_, (GXmlNode*) _tmp28_, &_inner_error_);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1820 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp29_ = bt;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp30_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp29_);
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp31_ = _tmp30_;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp31_ == 0.156, "bt.doubleval == 0.156");
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp32_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"a156.156\"/>", 0, &_inner_error_);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc5 = _tmp32_;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1849 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp33_ = bt;
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp34_ = doc5;
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp33_, (GXmlNode*) _tmp34_, &_inner_error_);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1874 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp35_ = bt;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp36_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp35_);
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp37_ = _tmp36_;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp37_ == 0.0, "bt.doubleval == 0.0");
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp38_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156.156b\"/>", 0, &_inner_error_);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc6 = _tmp38_;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1905 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp39_ = bt;
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp40_ = doc6;
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp39_, (GXmlNode*) _tmp40_, &_inner_error_);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1932 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp41_ = bt;
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp42_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp41_);
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp43_ = _tmp42_;
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp43_ == 156.156, "bt.doubleval == 156.156");
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp44_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype boolean=\"true\"/>", 0, &_inner_error_);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		doc7 = _tmp44_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1965 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp45_ = bt;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_doubleval (_tmp45_, 0.0);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp46_ = bt;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp47_ = doc7;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp46_, (GXmlNode*) _tmp47_, &_inner_error_);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc7);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1998 "SerializableBasicTypesTest.c"
			goto __catch104_g_error;
		}
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp48_ = bt;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp49_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp48_);
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp50_ = _tmp49_;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_vala_assert (_tmp50_ == 0.0, "bt.doubleval == 0.0");
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc7);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc6);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc5);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc4);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc3);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc2);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc1);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 2027 "SerializableBasicTypesTest.c"
	}
	goto __finally104;
	__catch104_g_error:
	{
		GError* e = NULL;
		FILE* _tmp51_ = NULL;
		const gchar* _tmp52_ = NULL;
		const gchar* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		e = _inner_error_;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_inner_error_ = NULL;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp51_ = stdout;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp52_ = e->message;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp53_ = string_to_string (_tmp52_);
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp54_ = g_strconcat ("ERROR: ", _tmp53_, NULL);
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_tmp55_ = _tmp54_;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		fprintf (_tmp51_, "%s", _tmp55_);
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_free0 (_tmp55_);
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 2060 "SerializableBasicTypesTest.c"
	}
	__finally104:
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error_);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		return;
#line 2071 "SerializableBasicTypesTest.c"
	}
}


static void ___lambda76__gtest_func (void) {
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	__lambda76_ ();
#line 2079 "SerializableBasicTypesTest.c"
}


void serializable_basic_type_test_add_tests (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/boolean/serialize", ___lambda72__gtest_func);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/boolean/deserialize", ___lambda73__gtest_func);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/integer", ___lambda74__gtest_func);
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/float", ___lambda75__gtest_func);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/double", ___lambda76__gtest_func);
#line 2094 "SerializableBasicTypesTest.c"
}


SerializableBasicTypeTest* serializable_basic_type_test_construct (GType object_type) {
	SerializableBasicTypeTest* self = NULL;
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTest*) gxml_test_construct (object_type);
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return self;
#line 2104 "SerializableBasicTypesTest.c"
}


SerializableBasicTypeTest* serializable_basic_type_test_new (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return serializable_basic_type_test_construct (TYPE_SERIALIZABLE_BASIC_TYPE_TEST);
#line 2111 "SerializableBasicTypesTest.c"
}


static gchar* serializable_basic_type_test_basic_type_real_node_name (GXmlSerializableObjectModel* base) {
	SerializableBasicTypeTestBasicType * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTestBasicType*) base;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = g_strdup ("basictype");
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	result = _tmp0_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return result;
#line 2127 "SerializableBasicTypesTest.c"
}


static gchar* serializable_basic_type_test_basic_type_real_to_string (GXmlSerializableObjectModel* base) {
	SerializableBasicTypeTestBasicType * self;
	gchar* result = NULL;
	GType _tmp0_ = 0UL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTestBasicType*) base;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = G_TYPE_FROM_INSTANCE ((GObject*) self);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp1_ = g_type_name (_tmp0_);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	result = _tmp2_;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return result;
#line 2149 "SerializableBasicTypesTest.c"
}


SerializableBasicTypeTestBasicType* serializable_basic_type_test_basic_type_construct (GType object_type) {
	SerializableBasicTypeTestBasicType * self = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTestBasicType*) gxml_serializable_object_model_construct (object_type);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return self;
#line 2159 "SerializableBasicTypesTest.c"
}


SerializableBasicTypeTestBasicType* serializable_basic_type_test_basic_type_new (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return serializable_basic_type_test_basic_type_construct (SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE);
#line 2166 "SerializableBasicTypesTest.c"
}


gboolean serializable_basic_type_test_basic_type_get_boolean (SerializableBasicTypeTestBasicType* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = self->priv->_boolean;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	result = _tmp0_;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return result;
#line 2181 "SerializableBasicTypesTest.c"
}


void serializable_basic_type_test_basic_type_set_boolean (SerializableBasicTypeTestBasicType* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = value;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_boolean = _tmp0_;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_notify ((GObject *) self, "boolean");
#line 2195 "SerializableBasicTypesTest.c"
}


gint serializable_basic_type_test_basic_type_get_integer (SerializableBasicTypeTestBasicType* self) {
	gint result;
	gint _tmp0_ = 0;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = self->priv->_integer;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	result = _tmp0_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return result;
#line 2210 "SerializableBasicTypesTest.c"
}


void serializable_basic_type_test_basic_type_set_integer (SerializableBasicTypeTestBasicType* self, gint value) {
	gint _tmp0_ = 0;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = value;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_integer = _tmp0_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_notify ((GObject *) self, "integer");
#line 2224 "SerializableBasicTypesTest.c"
}


gfloat serializable_basic_type_test_basic_type_get_floatval (SerializableBasicTypeTestBasicType* self) {
	gfloat result;
	gfloat _tmp0_ = 0.0F;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = self->priv->_floatval;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	result = _tmp0_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return result;
#line 2239 "SerializableBasicTypesTest.c"
}


void serializable_basic_type_test_basic_type_set_floatval (SerializableBasicTypeTestBasicType* self, gfloat value) {
	gfloat _tmp0_ = 0.0F;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = value;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_floatval = _tmp0_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_notify ((GObject *) self, "floatval");
#line 2253 "SerializableBasicTypesTest.c"
}


gdouble serializable_basic_type_test_basic_type_get_doubleval (SerializableBasicTypeTestBasicType* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = self->priv->_doubleval;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	result = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	return result;
#line 2268 "SerializableBasicTypesTest.c"
}


void serializable_basic_type_test_basic_type_set_doubleval (SerializableBasicTypeTestBasicType* self, gdouble value) {
	gdouble _tmp0_ = 0.0;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	_tmp0_ = value;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_doubleval = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_notify ((GObject *) self, "doubleval");
#line 2282 "SerializableBasicTypesTest.c"
}


static void serializable_basic_type_test_basic_type_class_init (SerializableBasicTypeTestBasicTypeClass * klass) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	serializable_basic_type_test_basic_type_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableBasicTypeTestBasicTypePrivate));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_basic_type_test_basic_type_real_node_name;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_basic_type_test_basic_type_real_to_string;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_basic_type_test_basic_type_get_property;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_basic_type_test_basic_type_set_property;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_basic_type_test_basic_type_finalize;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN, g_param_spec_boolean ("boolean", "boolean", "boolean", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER, g_param_spec_int ("integer", "integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL, g_param_spec_float ("floatval", "floatval", "floatval", -G_MAXFLOAT, G_MAXFLOAT, (gfloat) 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL, g_param_spec_double ("doubleval", "doubleval", "doubleval", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2309 "SerializableBasicTypesTest.c"
}


static void serializable_basic_type_test_basic_type_instance_init (SerializableBasicTypeTestBasicType * self) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv = SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_GET_PRIVATE (self);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_integer = 0;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_floatval = (gfloat) 0.0;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self->priv->_doubleval = 0.0;
#line 2322 "SerializableBasicTypesTest.c"
}


static void serializable_basic_type_test_basic_type_finalize (GObject* obj) {
	SerializableBasicTypeTestBasicType * self;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (serializable_basic_type_test_basic_type_parent_class)->finalize (obj);
#line 2332 "SerializableBasicTypesTest.c"
}


GType serializable_basic_type_test_basic_type_get_type (void) {
	static volatile gsize serializable_basic_type_test_basic_type_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_basic_type_test_basic_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableBasicTypeTestBasicTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_basic_type_test_basic_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableBasicTypeTestBasicType), 0, (GInstanceInitFunc) serializable_basic_type_test_basic_type_instance_init, NULL };
		GType serializable_basic_type_test_basic_type_type_id;
		serializable_basic_type_test_basic_type_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableBasicTypeTestBasicType", &g_define_type_info, 0);
		g_once_init_leave (&serializable_basic_type_test_basic_type_type_id__volatile, serializable_basic_type_test_basic_type_type_id);
	}
	return serializable_basic_type_test_basic_type_type_id__volatile;
}


static void _vala_serializable_basic_type_test_basic_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializableBasicTypeTestBasicType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	switch (property_id) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_value_set_boolean (value, serializable_basic_type_test_basic_type_get_boolean (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_value_set_int (value, serializable_basic_type_test_basic_type_get_integer (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_value_set_float (value, serializable_basic_type_test_basic_type_get_floatval (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		g_value_set_double (value, serializable_basic_type_test_basic_type_get_doubleval (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 2377 "SerializableBasicTypesTest.c"
		default:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 2383 "SerializableBasicTypesTest.c"
	}
}


static void _vala_serializable_basic_type_test_basic_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializableBasicTypeTestBasicType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	switch (property_id) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (self, g_value_get_boolean (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_integer (self, g_value_get_int (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_floatval (self, g_value_get_float (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_doubleval (self, g_value_get_double (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 2417 "SerializableBasicTypesTest.c"
		default:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
		break;
#line 2423 "SerializableBasicTypesTest.c"
	}
}


static void serializable_basic_type_test_class_init (SerializableBasicTypeTestClass * klass) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializableBasicTypesTest.vala"
	serializable_basic_type_test_parent_class = g_type_class_peek_parent (klass);
#line 2431 "SerializableBasicTypesTest.c"
}


static void serializable_basic_type_test_instance_init (SerializableBasicTypeTest * self) {
}


/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_basic_type_test_get_type (void) {
	static volatile gsize serializable_basic_type_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_basic_type_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableBasicTypeTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_basic_type_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableBasicTypeTest), 0, (GInstanceInitFunc) serializable_basic_type_test_instance_init, NULL };
		GType serializable_basic_type_test_type_id;
		serializable_basic_type_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableBasicTypeTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_basic_type_test_type_id__volatile, serializable_basic_type_test_type_id);
	}
	return serializable_basic_type_test_type_id__volatile;
}



